==> bibledit-0.9.tar.gz: bibledit-0.9/src/dialogeditextramatter.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGEDITEXTRAMATTER_H
#define INCLUDED_DIALOGEDITEXTRAMATTER_H

#include <gtk/gtk.h>
#include "scripture.h"
#include "ustring.h"
#include "extra_matter_utils.h"


class EditExtraMatterDialog
{
public:
  EditExtraMatterDialog (const string& projectname, EditExtraMatter edit_what);
  virtual ~EditExtraMatterDialog ();
  virtual int run ();
protected:
private:
  GtkWidget *dialogeditextramatter;
  GtkWidget *dialog_vbox1;
  GtkWidget *vbox1;
  GtkWidget *hbox1;
  GtkWidget *label1;
  GtkWidget *combo1;
  GtkWidget *combo_entry1;
  GtkWidget *button1;
  GtkWidget *vbox2;
  GtkWidget *markerlabel;
  GtkWidget *commentlabel;
  GtkWidget *scrolledwindow1;
  GtkWidget *textview1;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton1;
  GtkWidget *okbutton1;
  static void on_combo_entry1_changed (GtkEditable *editable, gpointer user_data);
  virtual void on_combo_entry ();
  static void on_button1_clicked (GtkButton *button, gpointer user_data);
  virtual void on_button1 ();
  static void on_okbutton1_clicked (GtkButton *button, gpointer user_data);
  virtual void on_okbutton ();
  static void on_cancelbutton1_clicked (GtkButton *button, gpointer user_data);
  virtual void on_cancelbutton ();
  string filename;
};


#endif

==> bibledit-1.4.tar.gz: bibledit-1.4/src/dialogeditextramatter.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGEDITEXTRAMATTER_H
#define INCLUDED_DIALOGEDITEXTRAMATTER_H

#include <gtk/gtk.h>
#include "scripture.h"
#include "ustring.h"
#include "extra_matter_utils.h"


class EditExtraMatterDialog
{
public:
  EditExtraMatterDialog (const ustring& projectname, EditExtraMatter edit_what);
  virtual ~EditExtraMatterDialog ();
  virtual int run ();
protected:
private:
  GtkWidget *dialogeditextramatter;
  GtkWidget *dialog_vbox1;
  GtkWidget *vbox1;
  GtkWidget *hbox1;
  GtkWidget *label1;
  GtkWidget *combo1;
  GtkWidget *combo_entry1;
  GtkWidget *button1;
  GtkWidget *vbox2;
  GtkWidget *markerlabel;
  GtkWidget *commentlabel;
  GtkWidget *scrolledwindow1;
  GtkWidget *textview1;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton1;
  GtkWidget *okbutton1;
  static void on_combo_entry1_changed (GtkEditable *editable, gpointer user_data);
  virtual void on_combo_entry ();
  static void on_button1_clicked (GtkButton *button, gpointer user_data);
  virtual void on_button1 ();
  static void on_okbutton1_clicked (GtkButton *button, gpointer user_data);
  virtual void on_okbutton ();
  static void on_cancelbutton1_clicked (GtkButton *button, gpointer user_data);
  virtual void on_cancelbutton ();
  ustring filename;
};


#endif
